﻿--
--
-- Core TABLE, INDEX, AND VIEW CREATION TEMPLATE
-- ------------------------------------------------------------
-- This script is a template for creating the tablespaces, tables,
-- indexes, and constraints required for the 'CORE' AML schema
-- if the AML Core tables are being stored in mySQL.
--
-- This script is only a template.  It must be customized
-- to the physical environment and volume of data expected.
--
--
-- Indexes may be added or removed as desired for performance reasons,
-- however, modifications to the ETL process might be necessary to
-- accomodate such changes, since it is often necessary to drop and
-- rebuild indexes during ETL for performance reasons.
--
-- This script assumes that the default storage engine has been
-- set to the desired storage engine. SAS recommends the InnoDB
-- engine.
--
-- ------------------------------------------------------------
-- ------------------------------------------------------------

SET FOREIGN_KEY_CHECKS = 0;


USE `AMLCORE`;


-- Create Core objects

CREATE TABLE AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM
(
	account_number        VARCHAR(50) NOT NULL,
	segment_id            VARCHAR(128) NOT NULL,
	expected_incoming_amount  NUMERIC(15,5) NULL,
	expected_outgoing_amount  NUMERIC(15,5) NULL,
	expected_incoming_count  NUMERIC(10) NULL,
	expected_outgoing_count  NUMERIC(10) NULL,
	increased_behavior_credit_amt  NUMERIC(15,5) NULL,
	increased_behavior_debit_amt  NUMERIC(15,5) NULL,
	increased_behavior_credit_cnt  NUMERIC(15,5) NULL,
	increased_behavior_debit_cnt  NUMERIC(15,5) NULL,
	expected_credit_ceiling_amount  NUMERIC(15,5) NULL,
	expected_debit_ceiling_amount  NUMERIC(15,5) NULL,
	last_activity_date    DATETIME NULL,
	 PRIMARY KEY (account_number,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSC_ACCOUNT_ANALYSIS_DIM ON FSC_ACCOUNT_ANALYSIS_DIM
(
	account_number,
	segment_id
)
;



CREATE TABLE AMLCORE.FSC_ACCOUNT_DIM
(
	account_key           BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL,
	account_number        VARCHAR(50) NOT NULL,
	line_of_business_name  VARCHAR(35) NULL,
	account_type_desc     VARCHAR(20) NOT NULL,
	account_currency_code  CHAR(3) NOT NULL,
	account_currency_name  VARCHAR(100) NOT NULL,
	account_registration_type_desc  VARCHAR(20) NULL,
	account_registration_name  VARCHAR(255) NULL,
	account_name          VARCHAR(35) NULL,
	alternate_name        VARCHAR(35) NULL,
	account_open_date     DATETIME NULL,
	account_close_date    DATETIME NULL,
	account_status_desc   VARCHAR(35) NULL,
	dormant_ind           CHAR(1) NULL,
	product_line_name     VARCHAR(35) NULL,
	product_category_name  VARCHAR(35) NULL,
	product_type_name     VARCHAR(35) NULL,
	product_name          VARCHAR(35) NULL,
	product_number        VARCHAR(25) NULL,
	account_tax_id        VARCHAR(35) NULL,
	account_tax_id_type_code  CHAR(1) NULL,
	account_tax_state_code  CHAR(3) NULL,
	account_primary_branch_name  VARCHAR(25) NULL,
	mailing_address_1     VARCHAR(35) NULL,
	mailing_address_2     VARCHAR(35) NULL,
	mailing_city_name     VARCHAR(35) NULL,
	mailing_state_code    CHAR(3) NULL,
	mailing_state_name    VARCHAR(35) NULL,
	mailing_postal_code   CHAR(10) NULL,
	mailing_country_code  CHAR(3) NULL,
	mailing_country_name  VARCHAR(100) NULL,
	currency_based_account_ind  CHAR(1) NULL,
	maturity_date         DATETIME NULL,
	original_loan_amount  NUMERIC(15,5) NULL,
	collateral_type_code  CHAR(10) NULL,
	collateral_type_desc  VARCHAR(35) NULL,
	insured_amount        NUMERIC(15,5) NULL,
	employee_ind          CHAR(1) NULL,
	letter_of_credit_onfile_ind  CHAR(1) NULL,
	cash_intensive_business_ind  CHAR(1) NULL,
	trade_finance_ind     CHAR(1) NULL,
	change_begin_date     DATETIME NULL,
	change_end_date       DATETIME NOT NULL DEFAULT '5999-01-01 00:00:00',
	change_current_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (account_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKACCOUNT ON FSC_ACCOUNT_DIM
(
	account_key,
	segment_id
)
;



CREATE INDEX XIE1ACCOUNT ON FSC_ACCOUNT_DIM
(
	account_number
)
;



CREATE INDEX XIE2ACCOUNT ON FSC_ACCOUNT_DIM
(
	account_name
)
;



CREATE INDEX XIE3ACCOUNT ON FSC_ACCOUNT_DIM
(
	account_tax_id
)
;



CREATE TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT
(
	transaction_key       BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL,
	branch_key            BIGINT NOT NULL,
	time_key              INTEGER NOT NULL,
	transaction_type_key BIGINT NOT NULL,
	transaction_status_key INTEGER NOT NULL,
	date_key              INTEGER NOT NULL,
	account_key BIGINT NOT NULL,
	country_key INTEGER NOT NULL,
	 PRIMARY KEY (transaction_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSC_ACCOUNT_EVENT_FACT ON FSC_ACCOUNT_EVENT_FACT
(
	transaction_key,
	segment_id
)
;



CREATE INDEX XIF1FSC_ACCOUNT_EVENT_FACT ON FSC_ACCOUNT_EVENT_FACT
(
	account_key,
	segment_id
)
;



CREATE INDEX XIF2FSC_ACCOUNT_EVENT_FACT ON FSC_ACCOUNT_EVENT_FACT
(
	date_key
)
;



CREATE TABLE AMLCORE.FSC_ACCOUNT_PROFILE_FACT
(
	account_number        VARCHAR(50) NOT NULL,
	month_key             INTEGER NOT NULL,
	segment_id            VARCHAR(128) NOT NULL,
	transactions_count    NUMERIC(9) NULL,
	deposits_count        NUMERIC(9) NULL,
	withdrawals_count     NUMERIC(9) NULL,
	wires_count           NUMERIC(9) NULL,
	cash_transactions_count  NUMERIC(9) NULL,
	account_value_amount  NUMERIC(18,5) NULL,
	total_transactions_amount  NUMERIC(18,5) NULL,
	total_credits_amount  NUMERIC(18,5) NULL,
	total_debits_amount   NUMERIC(18,5) NULL,
	total_cash_debits_amount  NUMERIC(18,5) NULL,
	total_cash_credits_amount  NUMERIC(18,5) NULL,
	total_wire_credits_amount  NUMERIC(18,5) NULL,
	total_wire_debits_amount  NUMERIC(18,5) NULL,
	beginning_balance_amount  NUMERIC(18,5) NULL,
	average_daily_balance_amount  NUMERIC(18,5) NULL,
	ending_cash_balance_amount  NUMERIC(18,5) NULL,
	max_account_value_amount  NUMERIC(18,5) NULL,
	min_account_value_amount  NUMERIC(18,5) NULL,
	avg_account_value_amount  NUMERIC(18,5) NULL,
	cust_initiated_trans_count  NUMERIC(9) NULL,
	largest_credit_amount  NUMERIC(18,5) NULL,
	largest_debit_amount  NUMERIC(18,5) NULL,
	 PRIMARY KEY (account_number,month_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKACCOUNT_SUMMARY_FACT ON FSC_ACCOUNT_PROFILE_FACT
(
	account_number,
	month_key,
	segment_id
)
;



CREATE INDEX XIF6ACCOUNT_SUMMARY_FACT ON FSC_ACCOUNT_PROFILE_FACT
(
	month_key,
	segment_id
)
;



CREATE TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
(
	transaction_key BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL,
	account_key BIGINT NOT NULL,
	branch_key BIGINT NOT NULL,
	transaction_type_key BIGINT NOT NULL,
	transaction_status_key INTEGER NOT NULL,
	trade_date_key        INTEGER NOT NULL,
	execution_time_key    INTEGER NOT NULL,
	posted_date_key       INTEGER NOT NULL,
	settlement_date_key   INTEGER NOT NULL,
	quantity_executed     NUMERIC(15,5) NULL,
	execution_price       NUMERIC(10,5) NULL,
	transaction_currency_key INTEGER NOT NULL,
	principal_amount_in_txn_ccy  NUMERIC(15,5) NULL,
	principal_amount      NUMERIC(15,5) NULL,
	principal_amount_in_acct_ccy  NUMERIC(15,5) NOT NULL,
	associate_key BIGINT NULL,
	 PRIMARY KEY (transaction_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKACCOUNT_POSITION_FACT ON FSC_ACCOUNT_TRADE_FACT
(
	transaction_key,
	segment_id
)
;



CREATE INDEX XIF1ACCOUNT_POSITION_FACT ON FSC_ACCOUNT_TRADE_FACT
(
	account_key,
	segment_id
)
;



CREATE TABLE AMLCORE.FSC_ASSOCIATE_DIM
(
	associate_key BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL,
	associate_number      VARCHAR(20) NULL,
	associate_first_name  VARCHAR(35) NULL,
	associate_last_name   VARCHAR(35) NULL,
	associate_middle_name  VARCHAR(25) NULL,
	associate_title_desc  VARCHAR(50) NULL,
	associate_status_desc  VARCHAR(35) NULL,
	street_address_1      VARCHAR(35) NULL,
	street_address_2      VARCHAR(35) NULL,
	street_city_name      VARCHAR(35) NULL,
	street_state_code     CHAR(3) NULL,
	street_state_name     VARCHAR(35) NULL,
	street_postal_code    CHAR(10) NULL,
	street_country_name   VARCHAR(100) NULL,
	street_country_code   CHAR(3) NULL,
	work_phone_number     VARCHAR(25) NULL,
	email_address         VARCHAR(35) NULL,
	branch_number         VARCHAR(25) NULL,
	branch_name           VARCHAR(35) NULL,
	change_begin_date     DATETIME NULL,
	change_end_date       DATETIME NOT NULL DEFAULT '5999-01-01 00:00:00'
,
	change_current_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (associate_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKASSOCIATE ON FSC_ASSOCIATE_DIM
(
	associate_key,
	segment_id
)
;



CREATE INDEX XIE1ASSOCIATE ON FSC_ASSOCIATE_DIM
(
	associate_number
)
;



CREATE INDEX XIE6ASSOCIATE ON FSC_ASSOCIATE_DIM
(
	associate_last_name
)
;



CREATE TABLE AMLCORE.FSC_BANK_DIM
(
	bank_key BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL,
	bank_number           VARCHAR(25) NULL,
	bank_chips_number     VARCHAR(25) NULL,
	bank_swift_number     VARCHAR(25) NULL,
	bank_name             VARCHAR(35) NULL,
	bank_address_1        VARCHAR(35) NULL,
	bank_address_2        VARCHAR(35) NULL,
	bank_city_name        VARCHAR(35) NULL,
	bank_state_code       CHAR(3) NULL,
	bank_state_name       VARCHAR(35) NULL,
	bank_postal_code      CHAR(10) NULL,
	bank_country_code     CHAR(3) NULL,
	bank_country_name     CHAR(35) NULL,
	bank_phone_number     VARCHAR(25) NULL,
	change_begin_date     DATETIME NULL,
	change_end_date       DATETIME NOT NULL,
	change_current_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (bank_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKBANK ON FSC_BANK_DIM
(
	bank_key,
	segment_id
)
;



CREATE INDEX XIE1BANK ON FSC_BANK_DIM
(
	bank_number
)
;



CREATE TABLE AMLCORE.FSC_BRANCH_DIM
(
	branch_key BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL,
	branch_type_desc      VARCHAR(10) NULL,
	branch_number         VARCHAR(40) NULL,
	branch_name           VARCHAR(100) NULL,
	street_address_1      VARCHAR(35) NULL,
	street_address_2      VARCHAR(35) NULL,
	street_city_name      VARCHAR(35) NULL,
	street_state_code     CHAR(3) NULL,
	street_state_name     VARCHAR(35) NULL,
	street_postal_code    CHAR(10) NULL,
	street_country_code   CHAR(3) NULL,
	street_country_name   VARCHAR(100) NULL,
	change_begin_date     DATETIME NULL,
	change_end_date       DATETIME NOT NULL DEFAULT '5999-01-01 00:00:00'
,
	change_current_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (branch_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKBRANCH ON FSC_BRANCH_DIM
(
	branch_key,
	segment_id
)
;



CREATE INDEX XIE1BRANCH ON FSC_BRANCH_DIM
(
	branch_number
)
;



CREATE INDEX XIE2BRANCH ON FSC_BRANCH_DIM
(
	branch_name
)
;



CREATE TABLE AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE
(
	bank_key BIGINT NOT NULL,
	transaction_key BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL,
	role_desc             VARCHAR(20) NULL,
	sequence_number       NUMERIC(2) NULL,
	 PRIMARY KEY (bank_key,transaction_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSC_CASH_FLOW_BANK_BRIDGE ON FSC_CASH_FLOW_BANK_BRIDGE
(
	bank_key,
	transaction_key,
	segment_id
)
;



CREATE INDEX XIF1FSC_CASH_FLOW_BANK_BRIDGE ON FSC_CASH_FLOW_BANK_BRIDGE
(
	bank_key,
	segment_id
)
;



CREATE INDEX XIF2FSC_CASH_FLOW_BANK_BRIDGE ON FSC_CASH_FLOW_BANK_BRIDGE
(
	transaction_key,
	segment_id
)
;



CREATE TABLE AMLCORE.FSC_CASH_FLOW_FACT
(
	transaction_key BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL,
	account_key BIGINT NOT NULL,
	country_key INTEGER NOT NULL,
	transaction_type_key BIGINT NOT NULL,
	time_key              INTEGER NOT NULL,
	date_key              INTEGER NOT NULL,
	transaction_status_key INTEGER NOT NULL,
	transaction_currency_key INTEGER NOT NULL,
	branch_key BIGINT NOT NULL,
	remitter_ext_party_key BIGINT NOT NULL,
	beneficiary_ext_party_key BIGINT NOT NULL,
	posted_date_key       INTEGER NULL,
	associate_key BIGINT NOT NULL,
	executing_party_key BIGINT NOT NULL,
	currency_amount       NUMERIC(15,5) NOT NULL,
	currency_amount_in_txn_ccy  NUMERIC(15,5) NOT NULL,
	currency_amount_in_account_ccy  NUMERIC(15,5) NOT NULL,
	secondary_account_key BIGINT NOT NULL,
	related_ind           CHAR(1) NOT NULL DEFAULT 'U',
	third_party_ind       CHAR(1) NULL,
	 PRIMARY KEY (transaction_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKACCOUNT_CREDITS_FACT ON FSC_CASH_FLOW_FACT
(
	transaction_key,
	segment_id
)
;



CREATE INDEX XIF1ACCOUNT_CREDITS_FACT ON FSC_CASH_FLOW_FACT
(
	account_key,
	segment_id
)
;



CREATE INDEX XIF12ACCOUNT_CREDITS_FACT ON FSC_CASH_FLOW_FACT
(
	executing_party_key,
	segment_id
)
;



CREATE INDEX XIF15ACCOUNT_CREDITS_FACT ON FSC_CASH_FLOW_FACT
(
	remitter_ext_party_key,
	segment_id
)
;



CREATE INDEX XIF16ACCOUNT_CREDITS_FACT ON FSC_CASH_FLOW_FACT
(
	beneficiary_ext_party_key,
	segment_id
)
;



CREATE INDEX XIF5ACCOUNT_CREDITS_FACT ON FSC_CASH_FLOW_FACT
(
	date_key
)
;



CREATE TABLE AMLCORE.FSC_CLASSIFIER_FACT
(
	party_number          VARCHAR(50) NOT NULL,
	month_key             INTEGER NOT NULL,
	segment_id            VARCHAR(128) NOT NULL,
	rc_pep                NUMERIC(1) NULL,
	rc_foreign_financial_inst  NUMERIC(1) NULL,
	rc_non_bank_financial_inst  NUMERIC(1) NULL,
	rc_foreign_corporation  NUMERIC(1) NULL,
	rc_deposit_broker     NUMERIC(1) NULL,
	rc_cash_intensive_business  NUMERIC(1) NULL,
	rc_professional_svcs_provider  NUMERIC(1) NULL,
	rc_private_banking    NUMERIC(1) NULL,
	rc_trust_or_asset_mgmt_acct  NUMERIC(1) NULL,
	rc_foreign_correspondent_acct  NUMERIC(1) NULL,
	rc_trade_finance      NUMERIC(1) NULL,
	rc_special_use_account  NUMERIC(1) NULL,
	rc_lending_activity   NUMERIC(1) NULL,
	rc_nondeposit_account  NUMERIC(1) NULL,
	rc_wires_count        NUMERIC(6) NULL,
	rc_funds_transfer_count  NUMERIC(6) NULL,
	rc_non_profit_org     NUMERIC(1) NULL,
	rc_funds_payment_svcs_count  NUMERIC(6) NULL,
	rc_internal_pep       NUMERIC(1) NULL,
	rc_high_risk_geography  NUMERIC(1) NULL,
	rc_monetary_instrument_count  NUMERIC(6) NULL,
	 PRIMARY KEY (party_number,month_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSC_CLASSIFIER_FACT ON FSC_CLASSIFIER_FACT
(
	party_number,
	month_key,
	segment_id
)
;



CREATE INDEX XIE1FSC_CLASSIFIER_FACT ON FSC_CLASSIFIER_FACT
(
	rc_pep
)
;



CREATE TABLE AMLCORE.FSC_COUNTRY_DIM
(
	country_key INTEGER NOT NULL,
	country_code_2        CHAR(2) NULL,
	country_code_3        CHAR(3) NULL,
	country_name          VARCHAR(100) NULL,
	 PRIMARY KEY (country_key)
)
;



CREATE UNIQUE INDEX XPKFSC_COUNTRY_DIM ON FSC_COUNTRY_DIM
(
	country_key
)
;



CREATE INDEX XIE1FSC_COUNTRY_DIM ON FSC_COUNTRY_DIM
(
	country_name
)
;



CREATE INDEX XIE2FSC_COUNTRY_DIM ON FSC_COUNTRY_DIM
(
	country_code_2
)
;



CREATE INDEX XIE3FSC_COUNTRY_DIM ON FSC_COUNTRY_DIM
(
	country_code_3
)
;



CREATE TABLE AMLCORE.FSC_CURRENCY_DIM
(
	currency_key INTEGER NOT NULL,
	currency_code         CHAR(3) NULL,
	currency_name         VARCHAR(100) NULL,
	 PRIMARY KEY (currency_key)
)
;



CREATE UNIQUE INDEX XPKFSC_CURRENCY_DIM ON FSC_CURRENCY_DIM
(
	currency_key
)
;



CREATE INDEX XIE1FSC_CURRENCY_DIM ON FSC_CURRENCY_DIM
(
	currency_code
)
;



CREATE INDEX XIE2FSC_CURRENCY_DIM ON FSC_CURRENCY_DIM
(
	currency_name
)
;



CREATE TABLE AMLCORE.FSC_DATE_DIM
(
	date_key              INTEGER NOT NULL,
	calendar_date         DATETIME NULL,
	calendar_date_sas     NUMERIC(8,0) NULL,
	calendar_date_dmy     CHAR(9) NULL,
	day_name              VARCHAR(9) NULL,
	day_name_short        CHAR(3) NULL,
	day_number_in_month   NUMERIC(2,0) NULL,
	day_number_in_year    NUMERIC(3,0) NULL,
	week_number_in_month  NUMERIC(1,0) NULL,
	week_number_in_year   NUMERIC(2,0) NULL,
	month_number_in_year  NUMERIC(2,0) NULL,
	month_key             INTEGER NULL,
	month_and_year        CHAR(6) NULL,
	month_name            VARCHAR(9) NULL,
	month_name_short      CHAR(3) NULL,
	quarter_name          CHAR(4) NULL,
	quarter_and_year      CHAR(6) NULL,
	month_name_3c         CHAR(3) NULL,
	quarter_name_2c       CHAR(2) NULL,
	quarter_name_4c       CHAR(4) NULL,
	year_2c               CHAR(2) NULL,
	year_4c               CHAR(4) NULL,
	holiday_ind           CHAR(1) NULL,
	holiday_name          CHAR(9) NULL,
	week_day_ind          CHAR(1) NULL,
	end_of_month_ind      CHAR(1) NULL,
	economic_release_desc  VARCHAR(20) NULL,
	economic_event_desc   VARCHAR(20) NULL,
	 PRIMARY KEY (date_key)
)
;



CREATE UNIQUE INDEX PKX01_DATE_KEY ON FSC_DATE_DIM
(
	date_key
)
;



CREATE INDEX BMX15_WEEK_DAY_FLAG ON FSC_DATE_DIM
(
	week_day_ind
)
;



CREATE INDEX BMX05_WEEK_NBR_MONTH ON FSC_DATE_DIM
(
	week_number_in_month
)
;



CREATE INDEX BMX06_WEEK_NBR_YEAR ON FSC_DATE_DIM
(
	week_number_in_year
)
;



CREATE INDEX BMX08_MONTH_KEY ON FSC_DATE_DIM
(
	month_key
)
;



CREATE INDEX BMX09_MONTH_YEAR ON FSC_DATE_DIM
(
	month_and_year
)
;



CREATE INDEX BMX11_MONTH_NAME_SHORT ON FSC_DATE_DIM
(
	month_name_short
)
;



CREATE INDEX BMX12_QUARTER ON FSC_DATE_DIM
(
	quarter_name
)
;



CREATE INDEX BMX13_QUARTER_YEAR ON FSC_DATE_DIM
(
	quarter_and_year
)
;



CREATE INDEX BMX14_YEAR ON FSC_DATE_DIM
(
	year_4c
)
;



CREATE INDEX BMX16_EOM ON FSC_DATE_DIM
(
	end_of_month_ind
)
;



CREATE INDEX BMX17_HOLIDAY_FLAG ON FSC_DATE_DIM
(
	holiday_ind
)
;



CREATE INDEX BMX06_QUARTER ON FSC_DATE_DIM
(
	quarter_name_2c
)
;



CREATE INDEX BMX18_HOLIDAY_NAME ON FSC_DATE_DIM
(
	holiday_name
)
;



CREATE INDEX BMX10_MONTH_NAME ON FSC_DATE_DIM
(
	month_name
)
;



CREATE INDEX BMX07_MONTH_NBR_YEAR ON FSC_DATE_DIM
(
	month_number_in_year
)
;



CREATE INDEX BMX04_DAY_NBR_YEAR ON FSC_DATE_DIM
(
	day_number_in_year
)
;



CREATE INDEX BMX03_DAY_NBR_MONTH ON FSC_DATE_DIM
(
	day_number_in_month
)
;



CREATE INDEX BMX01_DAY_NAME ON FSC_DATE_DIM
(
	day_name
)
;



CREATE INDEX BMX02_DAY_NAME_SHORT ON FSC_DATE_DIM
(
	day_name_short
)
;



CREATE TABLE AMLCORE.FSC_ENTITY_WATCH_LIST_DIM
(
	entity_watch_list_key BIGINT NOT NULL,
	entity_watch_list_number  VARCHAR(35) NOT NULL,
	watch_list_name       CHAR(4) NOT NULL,
	category_desc         VARCHAR(50) NULL,
	type_desc             VARCHAR(20) NULL,
	programs              VARCHAR(250) NULL,
	tax_id                VARCHAR(35) NULL,
	tax_id_type_code      CHAR(1) NULL,
	identification_id     VARCHAR(35) NULL,
	identification_type_desc  VARCHAR(35) NULL,
	date_of_birth         DATETIME NULL,
	year_of_birth         NUMERIC(4) NULL,
	place_of_birth        VARCHAR(100) NULL,
	deceased_ind          CHAR(1) NULL,
	first_name            VARCHAR(50) NULL,
	last_name             VARCHAR(50) NULL,
	middle_name           VARCHAR(100) NULL,
	entity_name           VARCHAR(200) NULL,
	match_code_individual  VARCHAR(15) NULL,
	match_code_organization  VARCHAR(20) NULL,
	entity_title          VARCHAR(200) NULL,
	occupation_desc       VARCHAR(200) NULL,
	address               VARCHAR(100) NULL,
	city_name             VARCHAR(50) NULL,
	state_name            VARCHAR(50) NULL,
	postal_code           CHAR(10) NULL,
	country_code          CHAR(3) NULL,
	country_name          VARCHAR(100) NULL,
	full_address          VARCHAR(300) NULL,
	match_code_full_address  VARCHAR(40) NULL,
	citizenship_country_code  CHAR(3) NULL,
	citizenship_country_name  VARCHAR(100) NULL,
	match_code_citizenship  VARCHAR(15) NULL,
	nationality_country_code  CHAR(3) NULL,
	nationality_country_name  VARCHAR(100) NULL,
	match_code_nationality  VARCHAR(15) NULL,
	org_country_of_business_code  VARCHAR(3) NULL,
	org_country_of_business_name  VARCHAR(100) NULL,
	match_code_org_country  VARCHAR(15) NULL,
	politically_exposed_person_ind  CHAR(1) NULL,
	create_date           DATETIME NULL,
	update_date           DATETIME NULL,
	exclude_ind           CHAR(1) NOT NULL,
	change_begin_date     DATETIME NOT NULL,
	change_end_date       DATETIME NOT NULL DEFAULT '5999-01-01 00:00:00'
,
	change_current_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (entity_watch_list_key)
)
;



CREATE UNIQUE INDEX XPKFSC_ENTITY_WATCH_LIST_DIM ON FSC_ENTITY_WATCH_LIST_DIM
(
	entity_watch_list_key
)
;



CREATE INDEX XIE1FSC_ENTITY_WATCH_LIST_DIM ON FSC_ENTITY_WATCH_LIST_DIM
(
	entity_watch_list_number
)
;



CREATE INDEX XIE4FSC_ENTITY_WATCH_LIST_DIM ON FSC_ENTITY_WATCH_LIST_DIM
(
	last_name
)
;



CREATE INDEX XIE2FSC_ENTITY_WATCH_LIST_DIM ON FSC_ENTITY_WATCH_LIST_DIM
(
	watch_list_name
)
;



CREATE TABLE AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM
(
	ext_party_account_key BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL,
	external_party_number  VARCHAR(100) NULL,
	ext_party_type_desc   VARCHAR(20) NULL,
	full_name             VARCHAR(35) NULL,
	last_name             VARCHAR(35) NULL,
	first_name            VARCHAR(35) NULL,
	middle_name           VARCHAR(35) NULL,
	birth_date            DATETIME NULL,
	party_tax_id          VARCHAR(35) NULL,
	party_tax_id_type_code  CHAR(1) NULL,
	match_code_organization  CHAR(20) NULL,
	match_code_individual  CHAR(15) NULL,
	match_code_street_address  CHAR(40) NULL,
	street_address_1      VARCHAR(35) NULL,
	street_address_2      VARCHAR(35) NULL,
	street_city_name      VARCHAR(35) NULL,
	street_state_code     CHAR(3) NULL,
	street_state_name     VARCHAR(35) NULL,
	street_postal_code    CHAR(10) NULL,
	street_country_code   CHAR(3) NULL,
	street_country_name   VARCHAR(100) NULL,
	account_number        VARCHAR(50) NULL,
	bank_key BIGINT NULL,
	branch_number         VARCHAR(25) NULL,
	branch_name           VARCHAR(35) NULL,
	citizenship_country_code  CHAR(3) NULL,
	citizenship_country_name  VARCHAR(100) NULL,
	residence_country_code  CHAR(3) NULL,
	residence_country_name  VARCHAR(100) NULL,
	phone_number_1        VARCHAR(25) NULL,
	phone_number_2        VARCHAR(25) NULL,
	identification_id     VARCHAR(35) NULL,
	identification_type_desc  CHAR(4) NULL,
	identification_state_code  CHAR(3) NULL,
	identification_country_code  CHAR(3) NULL,
	identification_country_name  VARCHAR(100) NULL,
	 PRIMARY KEY (ext_party_account_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSC_EXTERNAL_PARTY_ACCOUNT_DIM ON FSC_EXT_PARTY_ACCOUNT_DIM
(
	ext_party_account_key,
	segment_id
)
;



CREATE INDEX XIE1FSC_EXTERNAL_PARTY_ACCOUNT_DIM ON FSC_EXT_PARTY_ACCOUNT_DIM
(
	external_party_number
)
;



CREATE INDEX XIE2FSC_EXTERNAL_PARTY_ACCOUNT_DIM ON FSC_EXT_PARTY_ACCOUNT_DIM
(
	last_name
)
;



CREATE INDEX XIE4FSC_EXTERNAL_PARTY_ACCOUNT_DIM ON FSC_EXT_PARTY_ACCOUNT_DIM
(
	account_number
)
;



CREATE INDEX XIE5FSC_EXTERNAL_PARTY_ACCOUNT_DIM ON FSC_EXT_PARTY_ACCOUNT_DIM
(
	full_name
)
;



CREATE TABLE AMLCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE
(
	household_key BIGINT NOT NULL,
	account_key BIGINT NOT NULL,
	change_begin_date     DATETIME NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	change_end_date       DATETIME NOT NULL DEFAULT '5999-01-01 00:00:00',
	change_current_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (household_key,account_key,change_begin_date,segment_id)
)
;



CREATE UNIQUE INDEX XPKHOUSEHO ON FSC_HOUSEHOLD_ACCOUNT_BRIDGE
(
	household_key,
	account_key,
	change_begin_date,
	segment_id
)
;



CREATE INDEX XIF1HOUSEHO ON FSC_HOUSEHOLD_ACCOUNT_BRIDGE
(
	household_key,
	segment_id
)
;



CREATE INDEX XIF2HOUSEHO ON FSC_HOUSEHOLD_ACCOUNT_BRIDGE
(
	account_key,
	segment_id
)
;



CREATE TABLE AMLCORE.FSC_HOUSEHOLD_DIM
(
	household_key BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL,
	household_number      VARCHAR(50) NULL,
	household_type_desc   VARCHAR(20) NULL,
	street_address_1      VARCHAR(35) NULL,
	street_address_2      VARCHAR(35) NULL,
	street_city_name      VARCHAR(35) NULL,
	street_state_code     CHAR(3) NULL,
	street_state_name     VARCHAR(35) NULL,
	street_postal_code    VARCHAR(10) NULL,
	street_country_code   CHAR(3) NULL,
	street_country_name   VARCHAR(100) NULL,
	phone_number_1        VARCHAR(25) NULL,
	phone_number_2        VARCHAR(25) NULL,
	head_of_household_name  VARCHAR(35) NULL,
	employee_ind          CHAR(1) NULL,
	change_begin_date     DATETIME NULL,
	change_end_date       DATETIME NOT NULL DEFAULT '5999-01-01 00:00:00',
	change_current_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (household_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKHOUSEHOLD ON FSC_HOUSEHOLD_DIM
(
	household_key,
	segment_id
)
;



CREATE INDEX XIE1HOUSEHOLD ON FSC_HOUSEHOLD_DIM
(
	household_number,
	change_current_ind
)
;



CREATE INDEX XIE3HOUSEHOLD ON FSC_HOUSEHOLD_DIM
(
	head_of_household_name
)
;



CREATE INDEX XIE4HOUSEHOLD ON FSC_HOUSEHOLD_DIM
(
	phone_number_1
)
;



CREATE INDEX XIE5HOUSEHOLD ON FSC_HOUSEHOLD_DIM
(
	phone_number_2
)
;



CREATE TABLE AMLCORE.FSC_HOUSEHOLD_PARTY_BRIDGE
(
	party_key BIGINT NOT NULL,
	household_key BIGINT NOT NULL,
	change_begin_date     DATETIME NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	change_end_date       DATETIME NOT NULL DEFAULT '5999-01-01 00:00:00',
	change_current_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (party_key,household_key,change_begin_date,segment_id)
)
;



CREATE UNIQUE INDEX XPKHOUSEHOLD_CUSTOMER_BRIDGE ON FSC_HOUSEHOLD_PARTY_BRIDGE
(
	party_key,
	household_key,
	change_begin_date,
	segment_id
)
;



CREATE INDEX XIF1HOUSEHOLD_CUSTOMER_BRIDGE ON FSC_HOUSEHOLD_PARTY_BRIDGE
(
	party_key,
	segment_id
)
;



CREATE INDEX XIF2HOUSEHOLD_CUSTOMER_BRIDGE ON FSC_HOUSEHOLD_PARTY_BRIDGE
(
	household_key,
	segment_id
)
;



CREATE TABLE AMLCORE.FSC_LOCATION_WATCH_LIST_DIM
(
	location_watch_list_key BIGINT NOT NULL,
	location_watch_list_number  VARCHAR(35) NOT NULL,
	watch_list_name       CHAR(4) NOT NULL,
	program               VARCHAR(20) NULL,
	country_code          CHAR(3) NULL,
	country_name          VARCHAR(100) NULL,
	match_code_country_name  VARCHAR(15) NULL,
	create_date           DATETIME NULL,
	update_date           DATETIME NULL,
	exclude_ind           CHAR(1) NOT NULL,
	change_begin_date     DATETIME NOT NULL,
	change_end_date       DATETIME NOT NULL DEFAULT '5999-01-01 00:00:00'
,
	change_current_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (location_watch_list_key)
)
;



CREATE UNIQUE INDEX XPKFSC_LOCATION_WATCH_LIST_DIM ON FSC_LOCATION_WATCH_LIST_DIM
(
	location_watch_list_key
)
;



CREATE TABLE AMLCORE.FSC_MONTH_DIM
(
	month_key             INTEGER NOT NULL,
	segment_id            VARCHAR(128) NOT NULL,
	month_and_year        CHAR(6) NULL,
	month_name            VARCHAR(9) NULL,
	month_name_3c         CHAR(3) NULL,
	quarter_name_2c       CHAR(2) NULL,
	quarter_name_4c       CHAR(4) NULL,
	year_2c               CHAR(2) NULL,
	year_4c               CHAR(4) NULL,
	current_month_ind     CHAR(1) NULL,
	 PRIMARY KEY (month_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKMONTH_DIM ON FSC_MONTH_DIM
(
	month_key,
	segment_id
)
;



CREATE INDEX XIE1MONTH_DIM ON FSC_MONTH_DIM
(
	current_month_ind
)
;



CREATE TABLE AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE
(
	account_key BIGINT NOT NULL,
	party_key BIGINT NOT NULL,
	role_key              INTEGER NOT NULL,
	change_begin_date     DATETIME NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	role_desc             VARCHAR(20) NULL,
	change_end_date       DATETIME NOT NULL DEFAULT '5999-01-01 00:00:00',
	change_current_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (account_key,party_key,role_key,change_begin_date,segment_id)
)
;



CREATE UNIQUE INDEX XPKCUSTOMER_ACCOUNT_BRIDGE ON FSC_PARTY_ACCOUNT_BRIDGE
(
	account_key,
	party_key,
	role_key,
	change_begin_date,
	segment_id
)
;



CREATE INDEX XIF1CUSTOMER_ACCOUNT_BRIDGE ON FSC_PARTY_ACCOUNT_BRIDGE
(
	party_key,
	segment_id
)
;



CREATE INDEX XIF2CUSTOMER_ACCOUNT_BRIDGE ON FSC_PARTY_ACCOUNT_BRIDGE
(
	account_key,
	segment_id
)
;



CREATE TABLE AMLCORE.FSC_PARTY_DIM
(
	party_key BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR',
	party_number          VARCHAR(50) NOT NULL,
	party_type_desc       VARCHAR(20) NOT NULL,
	party_tax_id          VARCHAR(35) NULL,
	party_tax_id_type_code  CHAR(1) NULL,
	party_identification_id  VARCHAR(35) NULL,
	party_identification_type_desc  CHAR(4) NULL,
	party_id_state_code   CHAR(3) NULL,
	party_date_of_birth   DATETIME NULL,
	party_first_name      VARCHAR(35) NULL,
	party_last_name       VARCHAR(35) NULL,
	party_middle_name     VARCHAR(35) NULL,
	party_name            VARCHAR(35) NULL,
	doing_business_as_name  VARCHAR(35) NULL,
	party_status_desc     VARCHAR(20) NULL,
	ultimate_parent_name  VARCHAR(35) NULL,
	match_code_organization  CHAR(20) NULL,
	match_code_individual  CHAR(15) NULL,
	match_code_street_address  CHAR(40) NULL,
	match_code_mailing_address  CHAR(40) NULL,
	street_address_1      VARCHAR(35) NULL,
	street_address_2      VARCHAR(35) NULL,
	street_city_name      VARCHAR(35) NULL,
	street_state_code     CHAR(3) NULL,
	street_state_name     VARCHAR(35) NULL,
	street_postal_code    CHAR(10) NULL,
	street_country_code   CHAR(3) NULL,
	street_country_name   VARCHAR(100) NULL,
	mailing_address_1     VARCHAR(35) NULL,
	mailing_address_2     VARCHAR(35) NULL,
	mailing_city_name     VARCHAR(35) NULL,
	mailing_state_code    CHAR(3) NULL,
	mailing_state_name    VARCHAR(35) NULL,
	mailing_postal_code   CHAR(10) NULL,
	mailing_country_code  CHAR(3) NULL,
	mailing_country_name  VARCHAR(100) NULL,
	residence_country_code  CHAR(3) NULL,
	residence_country_name  VARCHAR(100) NULL,
	citizenship_country_code  CHAR(3) NULL,
	citizenship_country_name  VARCHAR(100) NULL,
	org_country_of_business_code  CHAR(3) NULL,
	org_country_of_business_name  VARCHAR(100) NULL,
	employee_ind          CHAR(1) NULL,
	employee_number       VARCHAR(20) NULL,
	employer_name         VARCHAR(35) NULL,
	employer_phone_number  VARCHAR(25) NULL,
	email_address         VARCHAR(35) NULL,
	occupation_desc       VARCHAR(35) NULL,
	industry_code         CHAR(10) NULL,
	industry_desc         VARCHAR(255) NULL,
	phone_number_1        VARCHAR(25) NULL,
	phone_number_2        VARCHAR(25) NULL,
	phone_number_3        VARCHAR(25) NULL,
	annual_income_amount  NUMERIC(10,0) NULL,
	net_worth_amount      NUMERIC(10,0) NULL,
	marital_status_desc   VARCHAR(20) NULL,
	last_contact_date     DATETIME NULL,
	politically_exposed_person_ind  CHAR(1) NOT NULL DEFAULT 'N',
	non_profit_org_ind    CHAR(1) NULL,
	customer_since_date   DATETIME NULL,
	last_susp_actv_rpt_date  DATETIME NULL,
	last_cash_trans_rpt_date  DATETIME NULL,
	last_risk_assessment_date  DATETIME NULL,
	risk_classification   NUMERIC(1) NULL,
	change_begin_date     DATETIME NULL,
	change_end_date       DATETIME NOT NULL DEFAULT '5999-01-01 00:00:00',
	change_current_ind    CHAR(1) NOT NULL,
	 PRIMARY KEY (party_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKCUSTOMER ON FSC_PARTY_DIM
(
	party_key,
	segment_id
)
;



CREATE INDEX XIE12CUSTOMER ON FSC_PARTY_DIM
(
	party_name
)
;



CREATE INDEX XIE13CUSTOMER ON FSC_PARTY_DIM
(
	party_number
)
;



CREATE INDEX XIE14CUSTOMER ON FSC_PARTY_DIM
(
	party_tax_id
)
;



CREATE INDEX XIE15CUSTOMER ON FSC_PARTY_DIM
(
	match_code_mailing_address
)
;



CREATE INDEX XIE16CUSTOMER ON FSC_PARTY_DIM
(
	match_code_street_address
)
;



CREATE INDEX XIE17CUSTOMER ON FSC_PARTY_DIM
(
	phone_number_1
)
;



CREATE INDEX XIE18CUSTOMER ON FSC_PARTY_DIM
(
	phone_number_2
)
;



CREATE INDEX XIE19CUSTOMER ON FSC_PARTY_DIM
(
	phone_number_3
)
;



CREATE INDEX XIE20CUSTOMER ON FSC_PARTY_DIM
(
	employer_name
)
;



CREATE INDEX XIE21CUSTOMER ON FSC_PARTY_DIM
(
	match_code_individual
)
;



CREATE INDEX XIE22CUSTOMER ON FSC_PARTY_DIM
(
	match_code_organization
)
;



CREATE INDEX XIE23CUSTOMER ON FSC_PARTY_DIM
(
	employer_phone_number
)
;



CREATE INDEX XIE7CUSTOMER ON FSC_PARTY_DIM
(
	party_last_name
)
;



CREATE TABLE AMLCORE.FSC_PARTY_PROFILE_FACT
(
	party_number          VARCHAR(50) NOT NULL,
	month_key             INTEGER NOT NULL,
	segment_id            VARCHAR(128) NOT NULL,
	aggregate_assets_amount  NUMERIC(18,5) NULL,
	transactions_count    NUMERIC(9) NULL,
	deposits_count        NUMERIC(9) NULL,
	withdrawals_count     NUMERIC(9) NULL,
	wires_count           NUMERIC(9) NULL,
	cash_transactions_count  NUMERIC(9) NULL,
	account_value_amount  NUMERIC(9) NULL,
	total_transactions_amount  NUMERIC(18,5) NULL,
	total_credits_amount  NUMERIC(9) NULL,
	total_debits_amount   NUMERIC(18,5) NULL,
	total_cash_debits_amount  NUMERIC(18,5) NULL,
	total_cash_credits_amount  NUMERIC(18,5) NULL,
	total_wire_credits_amount  NUMERIC(18,5) NULL,
	total_wire_debits_amount  NUMERIC(18,5) NULL,
	largest_credit_amount  NUMERIC(18,5) NULL,
	largest_debit_amount  NUMERIC(18,5) NULL,
	funds_payment_svcs_count  NUMERIC(9) NULL,
	funds_transfer_count  NUMERIC(9) NULL,
	monetary_instrument_count  NUMERIC(9) NULL,
	 PRIMARY KEY (party_number,month_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSC_PARTY_PROFILE_FACT ON FSC_PARTY_PROFILE_FACT
(
	party_number,
	month_key,
	segment_id
)
;



CREATE INDEX XIF1FSC_PARTY_PROFILE_FACT ON FSC_PARTY_PROFILE_FACT
(
	month_key,
	segment_id
)
;



CREATE TABLE AMLCORE.FSC_TIME_DIM
(
	time_key              INTEGER NOT NULL,
	time_hhmmss           CHAR(6) NULL,
	time_hh               CHAR(2) NULL,
	time_mm               CHAR(2) NULL,
	time_ss               CHAR(2) NULL,
	time_am_pm            CHAR(2) NULL,
	 PRIMARY KEY (time_key)
)
;



CREATE UNIQUE INDEX XPKTIME_DIM ON FSC_TIME_DIM
(
	time_key
)
;



CREATE INDEX XIE1TIME_DIM ON FSC_TIME_DIM
(
	time_hhmmss
)
;



CREATE TABLE AMLCORE.FSC_TRANSACTION_DIM
(
	transaction_key BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL,
	date_key              INTEGER NOT NULL,
	transaction_reference_number  VARCHAR(50) NOT NULL,
	transaction_description  VARCHAR(255) NULL,
	security_name         VARCHAR(35) NULL,
	deal_number           VARCHAR(35) NULL,
	 PRIMARY KEY (transaction_key,segment_id)
)
;



CREATE UNIQUE INDEX XPKFSC_TRANSACTION_DIM ON FSC_TRANSACTION_DIM
(
	transaction_key,
	segment_id
)
;



CREATE UNIQUE INDEX XAK1FSC_TRANSACTION_DIM ON FSC_TRANSACTION_DIM
(
	transaction_reference_number,
	segment_id
)
;



CREATE TABLE AMLCORE.FSC_TRANSACTION_STATUS_DIM
(
	transaction_status_key INTEGER NOT NULL,
	status_desc           VARCHAR(20) NULL,
	status_reason_desc    VARCHAR(35) NULL,
	 PRIMARY KEY (transaction_status_key)
)
;



CREATE UNIQUE INDEX XPKFSC_TRANSACTION_STATUS_DIM ON FSC_TRANSACTION_STATUS_DIM
(
	transaction_status_key
)
;



CREATE INDEX XIE1FSC_TRANSACTION_STATUS_DIM ON FSC_TRANSACTION_STATUS_DIM
(
	status_desc
)
;



CREATE INDEX XIE2FSC_TRANSACTION_STATUS_DIM ON FSC_TRANSACTION_STATUS_DIM
(
	status_reason_desc
)
;



CREATE TABLE AMLCORE.FSC_TRANSACTION_TYPE_DIM
(
	transaction_type_key BIGINT NOT NULL,
	funds_securities_code  CHAR(1) NULL,
	funds_securities_desc  VARCHAR(20) NULL,
	transaction_cdi_code  CHAR(1) NULL,
	transaction_cdi_desc  VARCHAR(20) NULL,
	primary_medium_desc   VARCHAR(20) NULL,
	secondary_medium_desc  VARCHAR(20) NULL,
	mechanism_desc        VARCHAR(20) NULL,
	 PRIMARY KEY (transaction_type_key)
)
;



CREATE UNIQUE INDEX XPKTRANSACTION ON FSC_TRANSACTION_TYPE_DIM
(
	transaction_type_key
)
;



CREATE INDEX XIE1FSC_TRANSACTION_TYPE_DIM ON FSC_TRANSACTION_TYPE_DIM
(
	funds_securities_code,
	funds_securities_desc
)
;



CREATE INDEX XIE2FSC_TRANSACTION_TYPE_DIM ON FSC_TRANSACTION_TYPE_DIM
(
	transaction_cdi_code,
	transaction_cdi_desc
)
;



CREATE INDEX XIE3FSC_TRANSACTION_TYPE_DIM ON FSC_TRANSACTION_TYPE_DIM
(
	primary_medium_desc,
	secondary_medium_desc
)
;


CREATE TABLE AMLCORE.FSC_PARTY_SEQUENCE
(
	next_sequence_id      BIGINT NOT NULL,
	segment_id            VARCHAR(128) NOT NULL DEFAULT 'BANK1KCTR'
);



create view amlcore.fsc_account_primary_owner_view as
select a.account_number as account_number, p.party_number as current_primary_owner_number
from amlcore.fsc_party_dim p
join amlcore.fsc_party_account_bridge b on p.party_key = b.party_key and b.change_current_ind = 'Y' and b.role_key = 1 and p.segment_id = b.segment_id
join amlcore.fsc_account_dim a on a.account_key = b.account_key and b.change_current_ind = 'Y' and b.segment_id = a.segment_id
where p.change_current_ind = 'Y'
;



ALTER TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT
	ADD FOREIGN KEY R_131 (account_key,segment_id) REFERENCES AMLCORE.FSC_ACCOUNT_DIM(account_key,segment_id)
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT
	ADD FOREIGN KEY R_132 (date_key) REFERENCES AMLCORE.FSC_DATE_DIM(date_key)
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT
	ADD FOREIGN KEY R_133 (transaction_type_key) REFERENCES AMLCORE.FSC_TRANSACTION_TYPE_DIM(transaction_type_key)
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT
	ADD FOREIGN KEY R_140 (time_key) REFERENCES AMLCORE.FSC_TIME_DIM(time_key)
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT
	ADD FOREIGN KEY R_157 (transaction_key,segment_id) REFERENCES AMLCORE.FSC_TRANSACTION_DIM(transaction_key,segment_id)
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT
	ADD FOREIGN KEY R_158 (branch_key,segment_id) REFERENCES AMLCORE.FSC_BRANCH_DIM(branch_key,segment_id)
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT
	ADD FOREIGN KEY R_160 (transaction_status_key) REFERENCES AMLCORE.FSC_TRANSACTION_STATUS_DIM(transaction_status_key)
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_EVENT_FACT
	ADD FOREIGN KEY R_161 (country_key) REFERENCES AMLCORE.FSC_COUNTRY_DIM(country_key)
;



ALTER TABLE AMLCORE.FSC_ACCOUNT_PROFILE_FACT
	ADD FOREIGN KEY R_6 (month_key,segment_id) REFERENCES AMLCORE.FSC_MONTH_DIM(month_key,segment_id)
;



ALTER TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
	ADD FOREIGN KEY R_165 (account_key,segment_id) REFERENCES AMLCORE.FSC_ACCOUNT_DIM(account_key,segment_id)
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
	ADD FOREIGN KEY R_166 (branch_key,segment_id) REFERENCES AMLCORE.FSC_BRANCH_DIM(branch_key,segment_id)
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
	ADD FOREIGN KEY R_167 (trade_date_key) REFERENCES AMLCORE.FSC_DATE_DIM(date_key)
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
	ADD FOREIGN KEY R_168 (execution_time_key) REFERENCES AMLCORE.FSC_TIME_DIM(time_key)
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
	ADD FOREIGN KEY R_169 (transaction_currency_key) REFERENCES AMLCORE.FSC_CURRENCY_DIM(currency_key)
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
	ADD FOREIGN KEY R_170 (transaction_type_key) REFERENCES AMLCORE.FSC_TRANSACTION_TYPE_DIM(transaction_type_key)
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
	ADD FOREIGN KEY R_171 (transaction_status_key) REFERENCES AMLCORE.FSC_TRANSACTION_STATUS_DIM(transaction_status_key)
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
	ADD FOREIGN KEY R_184 (transaction_key,segment_id) REFERENCES AMLCORE.FSC_TRANSACTION_DIM(transaction_key,segment_id)
;


ALTER TABLE AMLCORE.FSC_ACCOUNT_TRADE_FACT
	ADD FOREIGN KEY R_186 (associate_key,segment_id) REFERENCES AMLCORE.FSC_ASSOCIATE_DIM(associate_key,segment_id)
;



ALTER TABLE AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE
	ADD FOREIGN KEY R_175 (bank_key,segment_id) REFERENCES AMLCORE.FSC_BANK_DIM(bank_key,segment_id)
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE
	ADD FOREIGN KEY R_176 (transaction_key,segment_id) REFERENCES AMLCORE.FSC_CASH_FLOW_FACT(transaction_key,segment_id)
;



ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD FOREIGN KEY R_111 (transaction_type_key) REFERENCES AMLCORE.FSC_TRANSACTION_TYPE_DIM(transaction_type_key)
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD FOREIGN KEY R_113 (transaction_key,segment_id) REFERENCES AMLCORE.FSC_TRANSACTION_DIM(transaction_key,segment_id)
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD FOREIGN KEY R_149 (executing_party_key,segment_id) REFERENCES AMLCORE.FSC_PARTY_DIM(party_key,segment_id)
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD FOREIGN KEY R_154 (associate_key,segment_id) REFERENCES AMLCORE.FSC_ASSOCIATE_DIM(associate_key,segment_id)
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD FOREIGN KEY R_159 (transaction_status_key) REFERENCES AMLCORE.FSC_TRANSACTION_STATUS_DIM(transaction_status_key)
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD FOREIGN KEY R_178 (remitter_ext_party_key,segment_id) REFERENCES AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM(ext_party_account_key,segment_id)
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD FOREIGN KEY R_179 (beneficiary_ext_party_key,segment_id) REFERENCES AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM(ext_party_account_key,segment_id)
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD FOREIGN KEY FK_ACCOUNT_CREDIT (account_key,segment_id) REFERENCES AMLCORE.FSC_ACCOUNT_DIM(account_key,segment_id)
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD FOREIGN KEY FK_BRANCH_CREDIT (branch_key,segment_id) REFERENCES AMLCORE.FSC_BRANCH_DIM(branch_key,segment_id)
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD FOREIGN KEY FK_DATE_CREDIT (date_key) REFERENCES AMLCORE.FSC_DATE_DIM(date_key)
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD FOREIGN KEY FK_TIME_CREDIT (time_key) REFERENCES AMLCORE.FSC_TIME_DIM(time_key)
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD FOREIGN KEY R_85 (transaction_currency_key) REFERENCES AMLCORE.FSC_CURRENCY_DIM(currency_key)
;


ALTER TABLE AMLCORE.FSC_CASH_FLOW_FACT
	ADD FOREIGN KEY R_126 (country_key) REFERENCES AMLCORE.FSC_COUNTRY_DIM(country_key)
;



ALTER TABLE AMLCORE.FSC_CLASSIFIER_FACT
	ADD FOREIGN KEY R_181 (month_key,segment_id) REFERENCES AMLCORE.FSC_MONTH_DIM(month_key,segment_id)
;


ALTER TABLE AMLCORE.FSC_PARTY_PROFILE_FACT
	ADD FOREIGN KEY R_155 (month_key,segment_id) REFERENCES AMLCORE.FSC_MONTH_DIM(month_key,segment_id)
;

SET FOREIGN_KEY_CHECKS = 1;


-- --------------------------------------------------------------------------
-- Create views for CORE tables. Multibank functionality is not supported in
-- the MySQL version of AML. These views are created for consistency.
-- --------------------------------------------------------------------------
create view BANK1CORE.FSC_ACCOUNT_ANALYSIS_DIM as select * from AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_ACCOUNT_DIM as select * from AMLCORE.FSC_ACCOUNT_DIM where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_ACCOUNT_EVENT_FACT as select * from AMLCORE.FSC_ACCOUNT_EVENT_FACT where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_ACCOUNT_PROFILE_FACT as select * from AMLCORE.FSC_ACCOUNT_PROFILE_FACT where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_ACCOUNT_TRADE_FACT as select * from AMLCORE.FSC_ACCOUNT_TRADE_FACT where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_ASSOCIATE_DIM as select * from AMLCORE.FSC_ASSOCIATE_DIM where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_BANK_DIM as select * from AMLCORE.FSC_BANK_DIM where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_BRANCH_DIM as select * from AMLCORE.FSC_BRANCH_DIM where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_CASH_FLOW_BANK_BRIDGE as select * from AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_CASH_FLOW_FACT as select * from AMLCORE.FSC_CASH_FLOW_FACT where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_CLASSIFIER_FACT as select * from AMLCORE.FSC_CLASSIFIER_FACT where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_COUNTRY_DIM as select * from AMLCORE.FSC_COUNTRY_DIM;
create view BANK1CORE.FSC_CURRENCY_DIM as select * from AMLCORE.FSC_CURRENCY_DIM;
create view BANK1CORE.FSC_DATE_DIM as select * from AMLCORE.FSC_DATE_DIM;
create view BANK1CORE.FSC_ENTITY_WATCH_LIST_DIM as select * from AMLCORE.FSC_ENTITY_WATCH_LIST_DIM;
create view BANK1CORE.FSC_EXT_PARTY_ACCOUNT_DIM as select * from AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE as select * from AMLCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_HOUSEHOLD_DIM as select * from AMLCORE.FSC_HOUSEHOLD_DIM where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_HOUSEHOLD_PARTY_BRIDGE as select * from AMLCORE.FSC_HOUSEHOLD_PARTY_BRIDGE where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_LOCATION_WATCH_LIST_DIM as select * from AMLCORE.FSC_LOCATION_WATCH_LIST_DIM;
create view BANK1CORE.FSC_MONTH_DIM as select * from AMLCORE.FSC_MONTH_DIM where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_PARTY_ACCOUNT_BRIDGE as select * from AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_PARTY_DIM as select * from AMLCORE.FSC_PARTY_DIM where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_PARTY_PROFILE_FACT as select * from AMLCORE.FSC_PARTY_PROFILE_FACT where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_TIME_DIM as select * from AMLCORE.FSC_TIME_DIM;
create view BANK1CORE.FSC_TRANSACTION_DIM as select * from AMLCORE.FSC_TRANSACTION_DIM where segment_id = 'BANK1KCTR';
create view BANK1CORE.FSC_TRANSACTION_STATUS_DIM as select * from AMLCORE.FSC_TRANSACTION_STATUS_DIM;
create view BANK1CORE.FSC_TRANSACTION_TYPE_DIM as select * from AMLCORE.FSC_TRANSACTION_TYPE_DIM;
create view BANK1CORE.FSC_PARTY_SEQUENCE as select * from AMLCORE.FSC_PARTY_SEQUENCE where segment_id = 'BANK1KCTR';

create view BANK1KCTR.FSC_ACCOUNT_ANALYSIS_DIM as select * from AMLCORE.FSC_ACCOUNT_ANALYSIS_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_ACCOUNT_DIM as select * from AMLCORE.FSC_ACCOUNT_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_ACCOUNT_EVENT_FACT as select * from AMLCORE.FSC_ACCOUNT_EVENT_FACT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_ACCOUNT_PROFILE_FACT as select * from AMLCORE.FSC_ACCOUNT_PROFILE_FACT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_ACCOUNT_TRADE_FACT as select * from AMLCORE.FSC_ACCOUNT_TRADE_FACT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_ASSOCIATE_DIM as select * from AMLCORE.FSC_ASSOCIATE_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_BANK_DIM as select * from AMLCORE.FSC_BANK_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_BRANCH_DIM as select * from AMLCORE.FSC_BRANCH_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_CASH_FLOW_BANK_BRIDGE as select * from AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_CASH_FLOW_FACT as select * from AMLCORE.FSC_CASH_FLOW_FACT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_CLASSIFIER_FACT as select * from AMLCORE.FSC_CLASSIFIER_FACT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_COUNTRY_DIM as select * from AMLCORE.FSC_COUNTRY_DIM;
create view BANK1KCTR.FSC_CURRENCY_DIM as select * from AMLCORE.FSC_CURRENCY_DIM;
create view BANK1KCTR.FSC_DATE_DIM as select * from AMLCORE.FSC_DATE_DIM;
create view BANK1KCTR.FSC_ENTITY_WATCH_LIST_DIM as select * from AMLCORE.FSC_ENTITY_WATCH_LIST_DIM;
create view BANK1KCTR.FSC_EXT_PARTY_ACCOUNT_DIM as select * from AMLCORE.FSC_EXT_PARTY_ACCOUNT_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_HOUSEHOLD_ACCOUNT_BRIDGE as select * from AMLCORE.FSC_HOUSEHOLD_ACCOUNT_BRIDGE where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_HOUSEHOLD_DIM as select * from AMLCORE.FSC_HOUSEHOLD_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_HOUSEHOLD_PARTY_BRIDGE as select * from AMLCORE.FSC_HOUSEHOLD_PARTY_BRIDGE where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_LOCATION_WATCH_LIST_DIM as select * from AMLCORE.FSC_LOCATION_WATCH_LIST_DIM;
create view BANK1KCTR.FSC_MONTH_DIM as select * from AMLCORE.FSC_MONTH_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_PARTY_ACCOUNT_BRIDGE as select * from AMLCORE.FSC_PARTY_ACCOUNT_BRIDGE where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_PARTY_DIM as select * from AMLCORE.FSC_PARTY_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_PARTY_PROFILE_FACT as select * from AMLCORE.FSC_PARTY_PROFILE_FACT where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_TIME_DIM as select * from AMLCORE.FSC_TIME_DIM;
create view BANK1KCTR.FSC_TRANSACTION_DIM as select * from AMLCORE.FSC_TRANSACTION_DIM where segment_id = 'BANK1KCTR';
create view BANK1KCTR.FSC_TRANSACTION_STATUS_DIM as select * from AMLCORE.FSC_TRANSACTION_STATUS_DIM;
create view BANK1KCTR.FSC_TRANSACTION_TYPE_DIM as select * from AMLCORE.FSC_TRANSACTION_TYPE_DIM;
create view BANK1KCTR.FSC_PARTY_SEQUENCE as select * from AMLCORE.FSC_PARTY_SEQUENCE where segment_id = 'BANK1KCTR';

create view BANK1CORE.FSC_ACCOUNT_PRIMARY_OWNER_VIEW (
   account_number,
   current_primary_owner_number )
as
select a.account_number as account_number, p.party_number as current_primary_owner_number
from AMLCORE.fsc_party_dim p
join AMLCORE.fsc_party_account_bridge b on p.party_key = b.party_key and b.change_current_ind = 'Y' and b.role_key = 1
join AMLCORE.fsc_account_dim a on a.account_key = b.account_key and b.change_current_ind = 'Y'
where p.change_current_ind = 'Y'
and p.segment_id = 'BANK1KCTR'
and b.segment_id = 'BANK1KCTR'
and a.segment_id = 'BANK1KCTR'
;


create view BANK1KCTR.FSC_ACCOUNT_PRIMARY_OWNER_VIEW (
   account_number,
   current_primary_owner_number )
as
select a.account_number as account_number, p.party_number as current_primary_owner_number
from AMLCORE.fsc_party_dim p
join AMLCORE.fsc_party_account_bridge b on p.party_key = b.party_key and b.change_current_ind = 'Y' and b.role_key = 1
join AMLCORE.fsc_account_dim a on a.account_key = b.account_key and b.change_current_ind = 'Y'
where p.change_current_ind = 'Y'
and p.segment_id = 'BANK1KCTR'
and b.segment_id = 'BANK1KCTR'
and a.segment_id = 'BANK1KCTR'
;



CREATE VIEW BANK1KCTR.fsc_transaction_view (
   account_key,
   account_number,
   branch_key,
   date_key,
   time_key,
   transaction_type_key,
   transaction_key,
   currency_amount,
   transaction_reference_number,
   transaction_description,
   security_name,
   deal_number,
   bank_name_1,
   role_desc_1,
   bank_name_2,
   role_desc_2,
   bank_name_3,
   role_desc_3,
   bank_name_4,
   role_desc_4,
   bank_name_5,
   role_desc_5,
   bank_name_6,
   role_desc_6,
   segment_id )
as
SELECT
         CFF.account_key,
         ACC.account_number,
         CFF.branch_key,
         CFF.date_key,
         CFF.time_key,
         CFF.transaction_type_key,
         CFF.transaction_key,
         CFF.currency_amount,
         TD.transaction_reference_number,
         TD.transaction_description,
         TD.security_name,
         TD.deal_number,
         BD.BANK_NAME as bank_name_1,
         CFBB.Role_Desc as role_desc_1,
         BD2.BANK_NAME as bank_name_2,
         CFBB2.Role_Desc as role_desc_2,
         BD3.BANK_NAME as bank_name_3,
         CFBB3.Role_Desc as role_desc_3,
         BD4.BANK_NAME as bank_name_4,
         CFBB4.Role_Desc as role_desc_4,
         BD5.BANK_NAME as bank_name_5,
         CFBB5.Role_Desc as role_desc_5,
         BD6.BANK_NAME as bank_name_6,
         CFBB6.Role_Desc as role_desc_6,
         TD.segment_id
FROM     AMLCORE.FSC_CASH_FLOW_FACT CFF
         join AMLCORE.FSC_TRANSACTION_DIM TD on CFF.transaction_key = TD.transaction_key and CFF.segment_id = TD.segment_id
         join AMLCORE.FSC_ACCOUNT_DIM ACC ON CFF.account_key = ACC.account_key and CFF.segment_id = ACC.segment_id
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB on CFF.TRANSACTION_KEY = CFBB.TRANSACTION_KEY and CFBB.SEQUENCE_NUMBER = 1 AND CFF.segment_id = CFBB.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD on CFBB.BANK_KEY = BD.BANK_KEY and CFBB.SEGMENT_ID = BD.SEGMENT_ID       
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB2 on CFF.TRANSACTION_KEY = CFBB2.TRANSACTION_KEY and CFBB2.SEQUENCE_NUMBER = 2 AND CFF.segment_id = CFBB2.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD2 on CFBB2.BANK_KEY = BD2.BANK_KEY and CFBB2.SEGMENT_ID = BD2.SEGMENT_ID         
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB3 on CFF.TRANSACTION_KEY = CFBB3.TRANSACTION_KEY and CFBB3.SEQUENCE_NUMBER = 3 AND CFF.segment_id = CFBB3.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD3 on CFBB3.BANK_KEY = BD3.BANK_KEY and CFBB3.SEGMENT_ID = BD3.SEGMENT_ID
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB4 on CFF.TRANSACTION_KEY = CFBB4.TRANSACTION_KEY and CFBB4.SEQUENCE_NUMBER = 4 AND CFF.segment_id = CFBB4.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD4 on CFBB4.BANK_KEY = BD4.BANK_KEY and CFBB4.SEGMENT_ID = BD4.SEGMENT_ID
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB5 on CFF.TRANSACTION_KEY = CFBB5.TRANSACTION_KEY and CFBB5.SEQUENCE_NUMBER = 5 AND CFF.segment_id = CFBB5.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD5 on CFBB5.BANK_KEY = BD5.BANK_KEY and CFBB5.SEGMENT_ID = BD5.SEGMENT_ID
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB6 on CFF.TRANSACTION_KEY = CFBB6.TRANSACTION_KEY and CFBB6.SEQUENCE_NUMBER = 6 AND CFF.segment_id = CFBB6.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD6 on CFBB6.BANK_KEY = BD6.BANK_KEY and CFBB6.SEGMENT_ID = BD6.SEGMENT_ID
WHERE TD.segment_id = 'BANK1KCTR'
UNION ALL
select 
         AEF.account_key,
         ACC.account_number,         
         AEF.branch_key,
         AEF.date_key,
         AEF.time_key,
         AEF.transaction_type_key,
         AEF.transaction_key,
         0,
         TD.transaction_reference_number,
         TD.transaction_description,
         TD.security_name,
         TD.deal_number,
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         TD.segment_id
FROM     AMLCORE.FSC_ACCOUNT_EVENT_FACT AEF  
         join AMLCORE.FSC_ACCOUNT_DIM ACC ON AEF.account_key = ACC.account_key and AEF.segment_id = ACC.segment_id
         join AMLCORE.FSC_TRANSACTION_DIM TD on AEF.transaction_key = TD.transaction_key and AEF.segment_id = TD.segment_id
WHERE TD.segment_id = 'BANK1KCTR'         
UNION ALL
select 
         ATF.account_key,
         ACC.account_number,
         ATF.branch_key,
         ATF.trade_date_key as date_key,
         ATF.execution_time_key as time_key,
         ATF.transaction_type_key,
         ATF.transaction_key,
         ATF.principal_amount as currency_amount,
         TD.transaction_reference_number,
         TD.transaction_description,
         TD.security_name,
         TD.deal_number,
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         TD.segment_id
FROM     AMLCORE.FSC_ACCOUNT_TRADE_FACT ATF
         join AMLCORE.FSC_ACCOUNT_DIM ACC ON ATF.account_key = ACC.account_key and ATF.segment_id = ACC.segment_id         
         join AMLCORE.FSC_TRANSACTION_DIM TD on ATF.transaction_key = TD.transaction_key and ATF.segment_id = TD.segment_id         
WHERE TD.segment_id = 'BANK1KCTR'
;

CREATE VIEW BANK1CORE.fsc_transaction_view (
   account_key,
   account_number,
   branch_key,
   date_key,
   time_key,
   transaction_type_key,
   transaction_key,
   currency_amount,
   transaction_reference_number,
   transaction_description,
   security_name,
   deal_number,
   bank_name_1,
   role_desc_1,
   bank_name_2,
   role_desc_2,
   bank_name_3,
   role_desc_3,
   bank_name_4,
   role_desc_4,
   bank_name_5,
   role_desc_5,
   bank_name_6,
   role_desc_6,
   segment_id )
as
SELECT
         CFF.account_key,
         ACC.account_number,
         CFF.branch_key,
         CFF.date_key,
         CFF.time_key,
         CFF.transaction_type_key,
         CFF.transaction_key,
         CFF.currency_amount,
         TD.transaction_reference_number,
         TD.transaction_description,
         TD.security_name,
         TD.deal_number,
         BD.BANK_NAME as bank_name_1,
         CFBB.Role_Desc as role_desc_1,
         BD2.BANK_NAME as bank_name_2,
         CFBB2.Role_Desc as role_desc_2,
         BD3.BANK_NAME as bank_name_3,
         CFBB3.Role_Desc as role_desc_3,
         BD4.BANK_NAME as bank_name_4,
         CFBB4.Role_Desc as role_desc_4,
         BD5.BANK_NAME as bank_name_5,
         CFBB5.Role_Desc as role_desc_5,
         BD6.BANK_NAME as bank_name_6,
         CFBB6.Role_Desc as role_desc_6,
         TD.segment_id
FROM     AMLCORE.FSC_CASH_FLOW_FACT CFF
         join AMLCORE.FSC_TRANSACTION_DIM TD on CFF.transaction_key = TD.transaction_key and CFF.segment_id = TD.segment_id
         join AMLCORE.FSC_ACCOUNT_DIM ACC ON CFF.account_key = ACC.account_key and CFF.segment_id = ACC.segment_id
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB on CFF.TRANSACTION_KEY = CFBB.TRANSACTION_KEY and CFBB.SEQUENCE_NUMBER = 1 AND CFF.segment_id = CFBB.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD on CFBB.BANK_KEY = BD.BANK_KEY and CFBB.SEGMENT_ID = BD.SEGMENT_ID       
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB2 on CFF.TRANSACTION_KEY = CFBB2.TRANSACTION_KEY and CFBB2.SEQUENCE_NUMBER = 2 AND CFF.segment_id = CFBB2.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD2 on CFBB2.BANK_KEY = BD2.BANK_KEY and CFBB2.SEGMENT_ID = BD2.SEGMENT_ID         
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB3 on CFF.TRANSACTION_KEY = CFBB3.TRANSACTION_KEY and CFBB3.SEQUENCE_NUMBER = 3 AND CFF.segment_id = CFBB3.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD3 on CFBB3.BANK_KEY = BD3.BANK_KEY and CFBB3.SEGMENT_ID = BD3.SEGMENT_ID
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB4 on CFF.TRANSACTION_KEY = CFBB4.TRANSACTION_KEY and CFBB4.SEQUENCE_NUMBER = 4 AND CFF.segment_id = CFBB4.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD4 on CFBB4.BANK_KEY = BD4.BANK_KEY and CFBB4.SEGMENT_ID = BD4.SEGMENT_ID
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB5 on CFF.TRANSACTION_KEY = CFBB5.TRANSACTION_KEY and CFBB5.SEQUENCE_NUMBER = 5 AND CFF.segment_id = CFBB5.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD5 on CFBB5.BANK_KEY = BD5.BANK_KEY and CFBB5.SEGMENT_ID = BD5.SEGMENT_ID
         left join  AMLCORE.FSC_CASH_FLOW_BANK_BRIDGE CFBB6 on CFF.TRANSACTION_KEY = CFBB6.TRANSACTION_KEY and CFBB6.SEQUENCE_NUMBER = 6 AND CFF.segment_id = CFBB6.segment_id 
         left join AMLCORE.FSC_BANK_DIM BD6 on CFBB6.BANK_KEY = BD6.BANK_KEY and CFBB6.SEGMENT_ID = BD6.SEGMENT_ID
WHERE TD.segment_id = 'BANK1KCTR'
UNION ALL
select 
         AEF.account_key,
         ACC.account_number,         
         AEF.branch_key,
         AEF.date_key,
         AEF.time_key,
         AEF.transaction_type_key,
         AEF.transaction_key,
         0,
         TD.transaction_reference_number,
         TD.transaction_description,
         TD.security_name,
         TD.deal_number,
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         TD.segment_id
FROM     AMLCORE.FSC_ACCOUNT_EVENT_FACT AEF  
         join AMLCORE.FSC_ACCOUNT_DIM ACC ON AEF.account_key = ACC.account_key and AEF.segment_id = ACC.segment_id
         join AMLCORE.FSC_TRANSACTION_DIM TD on AEF.transaction_key = TD.transaction_key and AEF.segment_id = TD.segment_id
WHERE TD.segment_id = 'BANK1KCTR'         
UNION ALL
select 
         ATF.account_key,
         ACC.account_number,
         ATF.branch_key,
         ATF.trade_date_key as date_key,
         ATF.execution_time_key as time_key,
         ATF.transaction_type_key,
         ATF.transaction_key,
         ATF.principal_amount as currency_amount,
         TD.transaction_reference_number,
         TD.transaction_description,
         TD.security_name,
         TD.deal_number,
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         '',
         TD.segment_id
FROM     AMLCORE.FSC_ACCOUNT_TRADE_FACT ATF
         join AMLCORE.FSC_ACCOUNT_DIM ACC ON ATF.account_key = ACC.account_key and ATF.segment_id = ACC.segment_id         
         join AMLCORE.FSC_TRANSACTION_DIM TD on ATF.transaction_key = TD.transaction_key and ATF.segment_id = TD.segment_id         
WHERE TD.segment_id = 'BANK1KCTR'
;





